Module: RandomPort

Extended by:
Forwardable
Defined in:
lib/random-port/module.rb

Overview

Main module that contains all RandomPort classes and utilities.

This module provides a simple way to acquire random TCP ports that are guaranteed to be available for use. It includes a Pool class that manages port allocation and ensures thread safety.

Author

Yegor Bugayenko ([email protected])

Copyright

Copyright (c) 2018-2026 Yegor Bugayenko

License

MIT

Defined Under Namespace

Classes: Pool

Class Method Summary collapse

Class Method Details

.acquire ⇒ Object

.count ⇒ Object

.empty? ⇒ Object

.release ⇒ Object

.size ⇒ Object