Exception: RandomPort::Pool::Timeout
- Inherits:
-
StandardError
- Object
- StandardError
- RandomPort::Pool::Timeout
- Defined in:
- lib/random-port/pool.rb
Overview
Raised when a port cannot be acquired within the timeout period.
Raised when a port cannot be acquired within the timeout period.